@@ -8,15 +8,14 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
 from jx_base.language import is_op
-from mo_json.types import T_NUMBER
+from mo_json.types import JX_NUMBER
 
 
 class AbsOp(Expression):
-    _data_type = T_NUMBER
+    _jx_type = JX_NUMBER
 
     def __init__(self, *term):
         Expression.__init__(self, *term)
