@@ -8,24 +8,24 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
+from jx_base.expressions.to_integer_op import ToIntegerOp
 
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
-from jx_base.expressions.integer_op import ToIntegerOp
 from jx_base.expressions.literal import ZERO
 from jx_base.expressions.max_op import MaxOp
 from jx_base.expressions.to_text_op import ToTextOp
 from jx_base.language import is_op
-from mo_json import T_INTEGER
+from mo_json import JX_INTEGER
 
 
 class BasicIndexOfOp(Expression):
     """
-    PLACEHOLDER FOR BASIC value.indexOf(find, start) (CAN NOT DEAL WITH NULLS)
+    PLACEHOLDER FOR STRICT value.indexOf(find, start) (CAN NOT DEAL WITH NULLS)
+    RETURN -1 IF NOT FOUND
     """
 
-    _data_type = T_INTEGER
+    _jx_type = JX_INTEGER
 
     def __init__(self, value, find, start):
         Expression.__init__(self, value, find, start)
@@ -33,12 +33,14 @@ class BasicIndexOfOp(Expression):
         self.find = find
         self.start = start
 
+    def __call__(self, row, rownum=None, rows=None):
+        value = self.value(row)
+        find = self.find(row)
+        start = self.start(row)
+        return value.find(find, start)
+
     def __data__(self):
-        return {"basic.indexOf": [
-            self.value.__data__(),
-            self.find.__data__(),
-            self.start.__data__(),
-        ]}
+        return {"basic.indexOf": [self.value.__data__(), self.find.__data__(), self.start.__data__()]}
 
     def vars(self):
         return self.value.vars() | self.find.vars() | self.start.vars()
@@ -52,16 +54,10 @@ class BasicIndexOfOp(Expression):
     def partial_eval(self, lang):
         start = ToIntegerOp(MaxOp(ZERO, self.start)).partial_eval(lang)
         return self.lang.BasicIndexOfOp(
-            ToTextOp(self.value).partial_eval(lang),
-            ToTextOp(self.find).partial_eval(lang),
-            start
+            ToTextOp(self.value).partial_eval(lang), ToTextOp(self.find).partial_eval(lang), start,
         )
 
     def __eq__(self, other):
         if not is_op(other, BasicIndexOfOp):
             return False
-        return (
-            self.value == self.value
-            and self.find == other.find
-            and self.start == other.start
-        )
+        return self.value == self.value and self.find == other.find and self.start == other.start
