@@ -8,20 +8,17 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
 from jx_base.language import is_op
-from mo_json.types import T_BOOLEAN
-
-
+from mo_json.types import JX_BOOLEAN
 
 
 class BasicNotOp(Expression):
-    _data_type = T_BOOLEAN
+    _jx_type = JX_BOOLEAN
 
-    def __init__(self, *term):
-        Expression.__init__(self, *term)
+    def __init__(self, term):
+        Expression.__init__(self, term)
         self.term = term
 
     def __data__(self):
