@@ -8,14 +8,19 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions.base_multi_op import BaseMultiOp
+from jx_base.expressions.expression import Expression
 
 
-class CardinalityOp(BaseMultiOp):
-    op = "cardinality"
+class CardinalityOp(Expression):
+
+    def __init__(self, frum):
+        Expression.__init__(self, frum)
+        self.frum = frum
 
     def __call__(self, row, rownum, rows):
         values = self.terms(row, rownum, rows)
-        return len(set(values))
\ No newline at end of file
+        return len(set(values))
+
+    def __data__(self):
+        return {"cardinality": self.frum.__data__()}
\ No newline at end of file
