@@ -8,16 +8,14 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.literal import ZERO
 from jx_base.expressions.literal import is_literal
 from jx_base.expressions.null_op import NULL
-from jx_base.expressions.variable import Variable
-from jx_base.language import is_op, JX
-from mo_json import T_INTEGER
+from jx_base.expressions.variable import is_variable
 from mo_dots import is_missing
+from mo_json import JX_INTEGER
 
 
 class FindOp(Expression):
@@ -26,18 +24,21 @@ class FindOp(Expression):
     """
 
     has_simple_form = True
-    _data_type = T_INTEGER
+    _jx_type = JX_INTEGER
 
-    def __init__(self, value, find, **kwargs):
+    def __init__(self, value, find, start=ZERO):
         Expression.__init__(self, value, find)
-        self.value, self.find = value, find
-        self.default = kwargs.get("default", NULL)
-        self.start = kwargs.get("start", ZERO).partial_eval(JX)
+        self.value, self.find, self.start = value, find, start
         if self.start is NULL:
             self.start = ZERO
 
+    def __eq__(self, other):
+        if not isinstance(other, FindOp):
+            return False
+        return self.value == other.value and self.find == other.find and self.start == other.start
+
     def __data__(self):
-        if is_op(self.value, Variable) and is_literal(self.find):
+        if is_variable(self.value) and is_literal(self.find):
             output = {
                 "find": {self.value.var: self.find.value},
                 "start": self.start.__data__(),
@@ -47,8 +48,6 @@ class FindOp(Expression):
                 "find": [self.value.__data__(), self.find.__data__()],
                 "start": self.start.__data__(),
             }
-        if self.default is not NULL:
-            output["default"] = self.default.__data__()
         return output
 
     def __call__(self, row, rownum=None, rows=None):
@@ -62,23 +61,14 @@ class FindOp(Expression):
 
         i = value.find(find, start)
         if i == -1:
-            return self.default(row, rownum, rows)
+            return None
         return i
 
     def vars(self):
-        return (
-            self.value.vars()
-            | self.find.vars()
-            | self.default.vars()
-            | self.start.vars()
-        )
+        return self.value.vars() | self.find.vars() | self.start.vars()
 
     def map(self, map_):
-        return FindOp(
-            [self.value.map(map_), self.find.map(map_)],
-            start=self.start.map(map_),
-            default=self.default.map(map_),
-        )
+        return FindOp(self.value.map(map_), self.find.map(map_), self.start.map(map_))
 
     def invert(self, lang):
         return lang.MissingOp(self)
