@@ -8,10 +8,9 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
-from mo_json.types import T_NUMBER
+from mo_json.types import JX_NUMBER
 
 
 class FromUnixOp(Expression):
@@ -19,7 +18,7 @@ class FromUnixOp(Expression):
     FOR USING ON DATABASES WHICH HAVE A DATE COLUMNS: CONVERT TO UNIX
     """
 
-    _data_type = T_NUMBER
+    _jx_type = JX_NUMBER
 
     def __init__(self, *term):
         Expression.__init__(self, *term)
