@@ -8,7 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.literal import is_literal
@@ -22,7 +21,7 @@ class LastOp(Expression):
     def __init__(self, term):
         Expression.__init__(self, term)
         self.term = term
-        self._data_type = self.term.type
+        self._jx_type = self.term.jx_type
 
     def __data__(self):
         return {"last": self.term.__data__()}
@@ -50,8 +49,6 @@ class LastOp(Expression):
         term = self.term.partial_eval(lang)
         if is_op(self.term, LastOp):
             return term
-        elif jx_type_to_json_type(term.type) != OBJECT and not term.many:
-            return term
         elif term is NULL:
             return term
         elif is_literal(term):
