@@ -8,23 +8,21 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import value2json
 from jx_base.expressions.expression import Expression
 from mo_dots import Null, is_data
 from mo_future import is_text
 from mo_imports import expect, export
-from mo_json.types import value_to_jx_type
+from mo_json import value2json, value_to_jx_type
 
-DateOp, FALSE, TRUE, NULL = expect("DateOp", "FALSE", "TRUE", "NULL")
+(DateOp,
+ FALSE, TRUE, NULL) = expect("DateOp", "FALSE", "TRUE", "NULL")
 
 
 class Literal(Expression):
     """
     A literal JSON document
     """
-    op = "literal"
 
     def __new__(cls, term):
         if term == None:
@@ -33,6 +31,10 @@ class Literal(Expression):
             return TRUE
         if term is False:
             return FALSE
+        if term == 0:
+            return ZERO
+        if term == 1:
+            return ONE
         if is_text(term) and not term:
             return NULL
         if is_data(term) and term.get("date"):
@@ -41,8 +43,7 @@ class Literal(Expression):
         return object.__new__(cls)
 
     def __init__(self, value):
-
-        Expression.__init__(self, None)
+        Expression.__init__(self)
         self.simplified = True
         self._value = value
 
@@ -104,18 +105,25 @@ class Literal(Expression):
         return self.json
 
     @property
-    def type(self):
+    def jx_type(self):
         return value_to_jx_type(self._value)
 
     def partial_eval(self, lang):
-        return self
+        return lang.Literal(self.value)
 
     def str(self):
         return str(self.value)
 
 
-ZERO = Literal(0)
-ONE = Literal(1)
+ZERO = object.__new__(Literal)
+Literal.__init__(ZERO, 0)
+ONE = object.__new__(Literal)
+Literal.__init__(ONE, 1)
+NEG_ONE = object.__new__(Literal)
+Literal.__init__(NEG_ONE, -1)
+EMPTY_ARRAY = object.__new__(Literal)
+Literal.__init__(EMPTY_ARRAY, [])
+
 
 literal_op_ids = tuple()
 
