@@ -7,8 +7,7 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-
-from __future__ import absolute_import, division, unicode_literals
+from mo_dots import is_missing
 
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
@@ -16,11 +15,11 @@ from jx_base.expressions.not_op import NotOp
 from jx_base.expressions.true_op import TRUE
 from jx_base.language import is_op
 from mo_imports import export
-from mo_json.types import T_BOOLEAN
+from mo_json.types import JX_BOOLEAN
 
 
 class MissingOp(Expression):
-    _data_type = T_BOOLEAN
+    _jx_type = JX_BOOLEAN
 
     def __init__(self, term):
         Expression.__init__(self, term)
@@ -35,6 +34,9 @@ class MissingOp(Expression):
         else:
             return self.expr == other.expr
 
+    def __call__(self, row, rownum=None, rows=None):
+        return is_missing(self.expr(row, rownum, rows))
+
     def vars(self):
         return self.expr.vars()
 
@@ -48,7 +50,7 @@ class MissingOp(Expression):
         output = self.expr.missing(lang)
         if is_op(output, MissingOp):
             # break call cycle
-            return NotOp(output)
+            return lang.NotOp(output)
         else:
             return output.invert(lang)
 
