@@ -8,17 +8,16 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions.eq_op import EqOp
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
-from jx_base.language import is_op
-from mo_json.types import T_BOOLEAN
+from jx_base.expressions.literal import ZERO, ONE, is_literal
+from jx_base.language import is_op, value_compare
+from mo_json.types import JX_BOOLEAN
 
 
 class SqlEqOp(Expression):
-    _data_type = T_BOOLEAN
+    _jx_type = JX_BOOLEAN
 
     def __init__(self, *terms):
         Expression.__init__(self, *terms)
@@ -31,6 +30,13 @@ class SqlEqOp(Expression):
         return FALSE
 
     def __eq__(self, other):
-        if not is_op(other, EqOp):
-            return False
-        return self.lhs == other.lhs and self.rhs == other.rhs
+        return is_op(other, SqlEqOp) and self.lhs == other.lhs and self.rhs == other.rhs
+
+    def partial_eval(self, lang):
+        lhs = self.lhs.partial_eval(lang)
+        rhs = self.rhs.partial_eval(lang)
+
+        if is_literal(lhs) and is_literal(rhs):
+            return ZERO if value_compare(lhs.value, rhs.value) else ONE
+        else:
+            return lang.SqlEqOp(lhs, rhs)
