@@ -8,31 +8,26 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
-from mo_imports import export
-from mo_logs import Log
-
-from jx_base.expressions.and_op import AndOp
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
 from jx_base.expressions.literal import Literal
 from jx_base.expressions.not_op import NotOp
 from jx_base.expressions.null_op import NULL
 from jx_base.expressions.or_op import OrOp
-from jx_base.expressions.to_boolean_op import ToBooleanOp
 from jx_base.expressions.true_op import TRUE
 from jx_base.language import is_op
+from mo_imports import export
+from mo_logs import Log
 
 
 class WhenOp(Expression):
-    def __init__(self, when, **clauses):
+    def __init__(self, when, then=NULL, **clauses):
         Expression.__init__(self, when)
-
         self.when = when
-        self.then = clauses.get("then", NULL)
+        self.then = then
         self.els_ = clauses.get("else", NULL)
-        self._data_type = self.then.type | self.els_.type
+        self._jx_type = self.then.jx_type | self.els_.jx_type
 
     def __data__(self):
         return {
@@ -48,7 +43,7 @@ class WhenOp(Expression):
             return self.els_(row, rownum, rows)
 
     def __eq__(self, other):
-        if not isinstance(other, WhenOp):
+        if not is_op(other, WhenOp):
             return False
         return self.when == other.when and self.then == other.then and self.els_ == other.els_
 
@@ -56,26 +51,20 @@ class WhenOp(Expression):
         return self.when.vars() | self.then.vars() | self.els_.vars()
 
     def map(self, map_):
-        return WhenOp(
-            self.when.map(map_),
-            then=self.then.map(map_),
-            **{"else": self.els_.map(map_)}
-        )
+        return WhenOp(self.when.map(map_), then=self.then.map(map_), **{"else": self.els_.map(map_)})
 
     def missing(self, lang):
         return OrOp(
-            AndOp(self.when, self.then.missing(lang)),
-            AndOp(NotOp(self.when), self.els_.missing(lang)),
+            lang.AndOp(self.when, self.then.missing(lang)), lang.AndOp(NotOp(self.when), self.els_.missing(lang)),
         ).partial_eval(lang)
 
     def invert(self, lang):
         return OrOp(
-            AndOp(self.when, self.then.invert(lang)),
-            AndOp(NotOp(self.when), self.els_.invert(lang)),
+            lang.AndOp(self.when, self.then.invert(lang)), lang.AndOp(NotOp(self.when), self.els_.invert(lang)),
         ).partial_eval(lang)
 
     def partial_eval(self, lang):
-        when = ToBooleanOp(self.when).partial_eval(lang)
+        when = lang.ToBooleanOp(self.when).partial_eval(lang)
 
         if when is TRUE:
             return self.then.partial_eval(lang)
@@ -96,9 +85,9 @@ class WhenOp(Expression):
             if els_ is FALSE:
                 return FALSE
             elif els_ is TRUE:
-                return (NotOp(when)).partial_eval(lang)
+                return lang.NotOp(when).partial_eval(lang)
 
-        return WhenOp(when, then=then, **{"else": els_})
+        return lang.WhenOp(when, then=then, **{"else": els_})
 
 
 export("jx_base.expressions.base_multi_op", WhenOp)
