@@ -8,7 +8,6 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 from collections import deque
 from copy import copy
@@ -16,20 +15,24 @@ from datetime import datetime
 from decimal import Decimal
 from math import isnan
 
-from mo_dots import Data, data_types, listwrap, NullType, startswith_field, null_types
+from jx_base.utils import enlist
+from mo_dots import Data, data_types, startswith_field, null_types
 from mo_dots.lists import list_types, is_many
 from mo_future import (
     boolean_type,
     long,
     none_type,
     text,
-    transpose,
     function_type,
     get_function_arguments,
+    first,
 )
-from mo_logs import Log
+from mo_imports import delay_import
+from mo_logs import logger
 from mo_times import Date
 
+is_literal = delay_import("jx_base.expressions.literal.is_literal")
+
 _get = object.__getattribute__
 builtin_tuple = tuple
 
@@ -61,8 +64,7 @@ def next_language_id():
 def all_bases(bases):
     for b in bases:
         yield b
-        for y in all_bases(b.__bases__):
-            yield y
+        yield from all_bases(b.__bases__)
 
 
 # PROBLEM: Every operator of every language may have its own partial_eval(lang)
@@ -107,10 +109,13 @@ def partial_eval(self, lang):
     DISPATCH TO CLASS-SPECIFIC self.partial_eval(lang)
     """
     try:
-        if self.simplified:
+        if self.simplified and self.lang == lang:
             return self
         func = self.lookups["partial_eval"][lang.id]
         output = func(self, lang)
+        if output.lang is not lang and not is_literal(output) and func is not self.lookups["partial_eval"][JX.id]:
+            func(self, lang)
+            logger.error(f"expecting {lang}")
         output.simplified = True
         return output
     except Exception as cause:
@@ -118,7 +123,7 @@ def partial_eval(self, lang):
             func(self, lang)
         except Exception as e:
             pass
-        Log.error("Not expected", cause=cause)
+        logger.error("Not expected", cause=cause)
 
 
 def get_dispatcher_for(name):
@@ -128,14 +133,12 @@ def get_dispatcher_for(name):
             output = func(self, lang)
             return output
         except Exception as cause:
-            Log.error("problem", cause=cause)
+            logger.error("problem", cause=cause)
 
     return dispatcher
 
 
-BaseExpression = LanguageElement(
-    str("BaseExpression"), (object,), {"partial_eval": partial_eval}
-)
+BaseExpression = LanguageElement(str("BaseExpression"), (object,), {"partial_eval": partial_eval})
 
 
 class Language(object):
@@ -144,22 +147,20 @@ class Language(object):
         if not name:
             name = "JX"
             JX = self
-        self.name = name
+        self.lang_name = name
         self.ops = None
         self.id = next_language_id()
 
     def register_ops(self, module_vars):
         global JX
 
-        if self.name != "JX":
+        if self.lang_name != "JX":
             self.ops = copy(JX.ops)  # A COPY, IF ONLY TO KNOW IT WAS REPLACED
 
             double_dispatch_methods = tuple(sorted(set(self.ops[1].lookups.keys())))
         else:
             num_ops = 1 + max(
-                obj.get_id()
-                for obj in module_vars.values()
-                if isinstance(obj, type) and hasattr(obj, ID)
+                obj.get_id() for obj in module_vars.values() if isinstance(obj, type) and hasattr(obj, ID)
             )
             self.ops = [None] * num_ops
 
@@ -177,47 +178,49 @@ class Language(object):
             double_dispatch_methods = tuple(sorted(double_dispatch_methods))
 
         for _, new_op in list(module_vars.items()):
-            if is_Expression(new_op):
-                op_id = new_op.get_id()
-                jx_op = JX.ops[op_id]
-                # LET EACH LANGUAGE POINT TO OP CLASS
-                self.ops[op_id] = new_op
-                new_op.lang = self
-                try:
-                    _get(new_op, "op")
-                except AttributeError as _:
+            if not is_Expression(new_op):
+                continue
+            op_id = new_op.get_id()
+            jx_op = JX.ops[op_id]
+            # LET EACH LANGUAGE POINT TO OP CLASS
+            self.ops[op_id] = new_op
+            new_op.lang = self
+            try:
+                _get(new_op, "op")
+            except AttributeError as _:
+                if new_op.__name__.endswith("Op"):
                     new_op.op = new_op.__name__[:-2].lower()
-
-                # ENSURE THE partial_eval IS REGISTERED
-                if jx_op is None:
-                    for dd_method in double_dispatch_methods:
-                        member = _extract_method(new_op, dd_method)
-                        args = get_function_arguments(member)
-                        if args[:2] != ("self", "lang"):
-                            Log.error(
-                                "{{module}}.{{clazz}}.{{name}} is expecting (self,"
-                                " lang) parameters, minimum",
-                                module=new_op.__module__,
-                                clazz=new_op.__name__,
-                                name=dd_method,
-                            )
-                        new_op.lookups[dd_method] = [member]
-                elif jx_op.__name__ != new_op.__name__:
-                    Log.error("Logic error")
                 else:
-                    new_op.lookups = jx_op.lookups
-                    for dd_method in double_dispatch_methods:
-                        member = _extract_method(new_op, dd_method)
-                        jx_op.lookups[dd_method] += [member]
+                    new_op.op = new_op.__name__
 
-                    # COPY OTHER DEFINED METHODS
-                    others = list(vars(new_op).items())
-                    for n, v in others:
-                        if v is not None:
-                            o = getattr(jx_op, n, None)
-                            if o is None:
-                                setattr(jx_op, n, v)
-        if self.name == "JX":
+            # ENSURE THE partial_eval IS REGISTERED
+            if jx_op is None:
+                for dd_method in double_dispatch_methods:
+                    member = _extract_method(new_op, dd_method)
+                    args = get_function_arguments(member)
+                    if args[:2] != ("self", "lang"):
+                        logger.error(
+                            "{{module}}.{{clazz}}.{{name}} is expecting (self, lang) parameters, minimum",
+                            module=new_op.__module__,
+                            clazz=new_op.__name__,
+                            name=dd_method,
+                        )
+                    new_op.lookups[dd_method] = [member]
+            elif jx_op.__name__ != new_op.__name__:
+                logger.error("Logic error")
+            else:
+                new_op.lookups = jx_op.lookups
+                for dd_method in double_dispatch_methods:
+                    set_at(jx_op.lookups[dd_method], self.id, _extract_method(new_op, dd_method))
+
+                # COPY OTHER DEFINED METHODS
+                others = list(vars(new_op).items())
+                for n, v in others:
+                    if v is not None:
+                        o = getattr(jx_op, n, None)
+                        if o is None:
+                            setattr(jx_op, n, v)
+        if self.lang_name == "JX":
             # FINALLY, SWAP OUT THE BASE METHODS
             for dd_method in double_dispatch_methods:
                 existing = getattr(BaseExpression, dd_method, None)
@@ -230,31 +233,58 @@ class Language(object):
 
         else:
             # ENSURE THE ALL OPS ARE DEFINED ON THE NEW LANGUAGE
-            for base_op, new_op in transpose(JX.ops, self.ops):
-                if base_op and new_op is base_op:
-                    # MISSED DEFINITION, ADD ONE
-                    new_op = type(base_op.__name__, (base_op,), {})
-                    self.ops[new_op.get_id()] = new_op
-                    setattr(new_op, "lookups", base_op.lookups)
-                    for n, v in base_op.lookups.items():
-                        v += v[-1:]
+            for new_op, jx_op in zip(self.ops, JX.ops):
+                if not jx_op or new_op is not jx_op:
+                    continue  # ALREADY DEFINED
+                base_op = first(b for b in get_basis(new_op) if isinstance(b, LanguageElement))
+                if not base_op:
+                    logger.error("Expecting operator to inherit from LanguageElement")
+                new_op = type(base_op.__name__, (base_op,), {})
+                new_op.lang = self
+                self.ops[new_op.get_id()] = new_op
+                setattr(new_op, "lookups", base_op.lookups)
+
+                for n, v in jx_op.lookups.items():
+                    set_at(v, self.id, v[base_op.lang.id])
 
         # ENSURE THIS LANGUAGE INSTANCE POINTS TO ALL THE OPS BY NAME
         for o in self.ops[1:]:
             setattr(self, o.__name__, o)
 
     def __getitem__(self, item):
-        Log.error("Stop using")
+        logger.error("Stop using")
         if item == None:
-            Log.error("expecting operator")
+            logger.error("expecting operator")
         class_ = self.ops[item.get_id()]
         if class_.__name__ != item.__class__.__name__:
-            Log.error("programming error")
+            logger.error("programming error")
         item.__class__ = class_
         return item
 
     def __str__(self):
-        return self.name
+        return self.lang_name
+
+    def __repr__(self):
+        return self.lang_name
+
+
+def set_at(list, index, value):
+    """
+    Ensure the list is extended to accommodate the specified index if needed,
+    and set the value at that index.
+    """
+    if index >= len(list):
+        list.extend([None] * (index - len(list) + 1))
+    list[index] = value
+
+
+def get_basis(cls):
+    """
+    RETURN ALL BASE CLASSES, UP THE FAMILY TREE, object LAST
+    """
+    yield cls
+    for base_class in cls.__bases__:
+        yield from get_basis(base_class)
 
 
 def is_op(call, op) -> bool:
@@ -277,7 +307,7 @@ def is_expression(call):
     except Exception:
         output = False
     # if output != isinstance(call, Expression):
-    #     Log.error("programmer error")
+    #     logger.error("programmer error")
     return output
 
 
@@ -303,8 +333,8 @@ def value_compare(left, right, ordering=1):
             elif right == None:
                 return -ordering
 
-            left = listwrap(left)
-            right = listwrap(right)
+            left = enlist(left)
+            right = enlist(right)
             for a, b in zip(left, right):
                 c = value_compare(a, b) * ordering
                 if c != 0:
@@ -354,11 +384,8 @@ def value_compare(left, right, ordering=1):
         else:
             return 0
     except Exception as e:
-        Log.error(
-            "Can not compare values {{left}} to {{right}}",
-            left=left,
-            right=right,
-            cause=e,
+        logger.error(
+            "Can not compare values {{left}} to {{right}}", left=left, right=right, cause=e,
         )
 
 
@@ -368,7 +395,7 @@ def type_order(dtype, ordering):
         if dtype in null_types:
             return ordering * 10
         else:
-            Log.warning("type will be treated as its own type while sorting")
+            logger.warning("type will be treated as its own type while sorting")
             TYPE_ORDER[dtype] = 6
             return 6
     return o
