@@ -7,11 +7,11 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions import LtOp as LtOp_
+
+from jx_base.expressions import LtOp as _LtOp
 from jx_python.expressions._utils import _inequality_to_python
 
 
-class LtOp(LtOp_):
+class LtOp(_LtOp):
     to_python = _inequality_to_python
