@@ -7,11 +7,11 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions import LteOp as LteOp_
+
+from jx_base.expressions import LteOp as _LteOp
 from jx_python.expressions._utils import _inequality_to_python
 
 
-class LteOp(LteOp_):
+class LteOp(_LteOp):
     to_python = _inequality_to_python
