@@ -7,10 +7,10 @@
 #
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
-from __future__ import absolute_import, division, unicode_literals
-
-from jx_base.expressions import RangeOp as RangeOp_
 
 
-class RangeOp(RangeOp_):
-    pass
\ No newline at end of file
+from jx_base.expressions import RangeOp as _RangeOp
+
+
+class RangeOp(_RangeOp):
+    pass
