@@ -8,19 +8,19 @@
 # Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 
-from __future__ import absolute_import, division, unicode_literals
 
 import math
 
-from jx_base.models.container import Container
-from jx_base.expressions import jx_expression
-from jx_base.language import is_expression
-from mo_dots import Data, FlatList, Null, listwrap, dict_to_data
+from mo_dots import FlatList, Null, dict_to_data
 from mo_dots.lists import list_types
 from mo_future import binary_type, text
 from mo_logs import Log
 from mo_logs.exceptions import Except
 
+from jx_base.expressions import jx_expression
+from jx_base.language import is_expression
+from jx_base.models.container import Container
+from jx_base.utils import enlist
 from jx_python.expressions import jx_expression_to_function
 
 
@@ -40,7 +40,7 @@ def groupby(data, keys=None, contiguous=False):
         if not data:
             return Null
 
-        keys = listwrap(keys)
+        keys = enlist(keys)
         if not contiguous:
             from jx_python import jx
 
